==> nextcloud-app-calendar-1%3A1.7.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/lv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendārs",
    "%s has published the calendar »%s«" : "%s dalijās ar kalendāru »%s«",
    "Hello," : "Sveicināti,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Mēs jūs vēlējāmies informēt, ka %s publicēja kalendāru »%s«.",
    "Open »%s«" : "Atvērt »%s«",
    "Cheers!" : "Priekā!",
    "Recipient" : "Saņēmējs",
    "URL violates local access rules" : "Saite pārkāpj lokālos pieejas noteikumus",
    "The remote server did not give us access to the calendar (HTTP 404 error)" : "Attālais serveris mums nedeva piekļuvi kalendāram (HTTP 404 kļūda)",
    "Too many redirects. Aborting ..." : "Pārāk daudz novirzīšanas gadījumu. Pārtrauc ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Attālais serveris nedeva mums piekļuvi kalendāram (HTTP {%s} kļūda)",
    "Error connecting to remote server" : "Kļūda, veidojot savienojumu ar attālo serveri",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Attālā servera resursu pieprasījumam, radās kļūda. Tas varētu būt saistīts ar sertifikātu neatbilstība",
    "Error requesting resource on remote server" : "Attālā servera resursu pieprasījuma kļūda",
    "Individual" : "Individuāls",
    "Group" : "Grupa",
    "Resource" : "Resurss",
    "Room" : "Istaba",
    "Unknown" : "Nezināms",
    "Required" : "Nepieciešams",
    "Optional" : "Neobligāts",
    "Does not attend" : "Neieradās",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūs atrodaties nezināmā laika zonā ({tz}), pārslēdz atpakaļ uz UTC",
    "Please create a calendar first." : "Lūdzu vispirms izveido kalendāru.",
    "New event" : "Jauns notikums",
    "CalDAV address for clients" : "CalDAV adrese klientiem",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Daži notikumi šajā kalendārā ir bojāti. Papildu informācijai pārbaudiet JS konsoli.",
    "Share Calendar" : "Koplietot kalendāru",
    "Shared" : "Koplietots",
    "Could not save WebCal-calendar" : "Neizdevās saglabāt WebCal kalendāru",
    "WebDAV address for subscriptions" : "WebDAV adrese abonementiem",
    "Email sent." : "E-pasts nosūtīts.",
    "Could not send your email." : "Neizdevās nosūtīt jūsu e-pastu.",
    "group" : "grupa",
    "circle" : "aplis",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Reminders" : "Atgādinājumi",
    "Repeating" : "Atkārtojas",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Confirmed" : "Apstiprināts",
    "Tentative" : "Mēģinājums",
    "Cancelled" : "Atcelts",
    "Please add a title." : "Lūdzu, pievienojiet virsrakstu.",
    "Please select a calendar." : "Lūdzu, izvēlieties kalendāru.",
    "The event can not end before it starts." : "Notikums nevar beigties pirms tas sākas.",
    "Global" : "Globāls",
    "None" : "Nav",
    "Every day" : "Katru dienu",
    "Every week" : "Katru nedēļu",
    "Every month" : "Katru mēnesi",
    "Every year" : "Katru gadu",
    "never" : "nekad",
    "after" : "pēc",
    "Automatic ({timezone})" : "Automātiski ({timezone})",
    "How about getting started by importing some calendars?" : "Kā uzsākt darbu, importējot dažus kalendārus?",
    "At time of event" : "Notikuma laikā",
    "5 minutes before" : "5 minūtes pirms",
    "10 minutes before" : "10 minūtes pirms",
    "15 minutes before" : "15 minūtes pirms",
    "30 minutes before" : "30 minūtes pirms",
    "1 hour before" : "1 stundu pirms",
    "2 hours before" : "2 stundas pirms",
    "Custom" : "Pielāgots",
    "Audio" : "Audio",
    "Email" : "E-pasts",
    "Pop-up" : "Paziņojums",
    "sec" : "sek",
    "min" : "min",
    "hours" : "stundas",
    "days" : "dienas",
    "week" : "nedēļa",
    "before" : "pirms",
    "start" : "sākums",
    "end" : "beigas",
    "Editing reminders of unknown type not supported." : "Nezināma tipa atgādinājumu rediģēšana netiek atbalstīta",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Successfully imported {imported} objects" : "Veiksmīgi importēja {imported} objektus.",
    "Imported {imported} out of {all}, skipped one duplicate" : "Importēja {imported} no {all}, izlaida vienu dublikātu",
    "Imported {imported} out of {all}, one failure" : "Importēja {imported} no {all}, viena kļūme",
    "Imported {imported} out of {all}, {errors} failures" : "Importēja {imported} no {all}, {errors} kļūmes",
    "Imported {imported} out of {all}, skipped {duplicates} duplicates" : "Importēja {imported} no {all}, izlaida {duplicates} dublikātus",
    "{type} {time} before the event starts" : "{type} {time} pirms notikuma sākuma",
    "{type} {time} before the event ends" : "{type} {time} pirms notikuma beigām",
    "{type} {time} after the event starts" : "{type} {time} pēc notikuma sākuma",
    "{type} {time} after the event ends" : "{type} {time} pēc notikuma beigām",
    "Email at the event's start" : "Notikumam sākoties, nosūtīt e-apstu",
    "{type} at the event's start" : "{type} notikuma sākumā",
    "{type} at the event's end" : "{type} notikuma beigās",
    "{type} at {time}" : "{type}  {time}",
    "{calendar} shared by {owner}" : "{calendar} koplietoja {owner}",
    "Please enter a valid WebCal-URL" : "Lūdzu norādiet derīgu WebCal adresi",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Kļūda WebCal protokola maršrutēšanā. Sazinieties ar administratoru, lai uzzinātu vairāk.",
    "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
    "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite team’s matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events.\n* 🙈 **We’re not reinventing the wheel!** Based on the great [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries." : "Kalendāra lietotne ir grafiskais interfeiss priekš Nextcloud iebūvētā CalDAV servera. Tas ļauj vienkārši sinhronizēt notikumus no vairākām ierīcēm ar tavu Nextcloud serveri un rediģēt tos tiešsaistē.\n\n* 🚀 **Savienojums ar citām Nextcloud lietotnēm!** Pašlaik kontaktiem - drīz vēl vairāk.\n* 🌐 **WebCal Atbalsts!** Gribi redzēt savas mīļākās komandas spēles dienas savā kalendārā? Nav problēmu!\n* 🙋 **Ciemiņi!** Uzaicini cilvēkus uz saviem notikumiem.\n* 🙈 **Mēs nemēģinam atkal izgudrot riteni!** Bazēts uz foršājām [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) un [fullcalendar](https://github.com/fullcalendar/fullcalendar) biblotēkām.",
    "Title of the Event" : "Notikuma nosaukums",
    "Starts" : "Sākas",
    "Ends" : "Beidzas",
    "All day Event" : "Visas dienas notikums",
    "Delete" : "Dzēst",
    "Cancel" : "Atcelt",
    "More ..." : "Vairāk ...",
    "Create" : "Izveidot",
    "Update" : "Atjaunināt",
    "Close" : "Aizvērt",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "Event status" : "Notikum statuss",
    "Visibility when sharing" : "Redzamība ja koplietots",
    "Export" : "Eksportēt",
    "%s has published the calendar %s" : "%s dalijās ar kalendāru %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Ņemiet vērā, ka %s dalijās ar kalendāru {boldstart}%s{boldend}.",
    "Click here to access it" : "Noklikšķiniet šeit, lai piekļūtu",
    "We wanted to inform you that %s has published the calendar %s." : "Ņemiet vērā, ka %s dalījās ar kalendāru %s.",
    "Click on the link below to access it" : "Spiediet uz saites zemāk, lai tam piekļūtu",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "Today" : "Šodien",
    "More" : "Vairāk",
    "Edit" : "Rediģēt",
    "Link" : "Saite",
    "iCal link" : "iCal saite",
    "Download" : "Lejupielādēt",
    "can edit" : "var rediģēt",
    "Share link" : "Koplietot saiti",
    "Public access" : "Publiska piekļuve",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "New Calendar" : "Jauns kalendārs",
    "Name" : "Nosaukums",
    "New Subscription" : "Jauns abonements",
    "Go back" : "Atpakaļ",
    "Go forward" : "Uz priekšu",
    "Calendar does not exist" : "Kalendārs nepastāv",
    "Maybe you got a wrong link or the calendar was unshared?" : "Iespējams jūs saņēmāt nepareizu saiti, vai kalendārs vairs nav koplietots.",
    "Edit event" : "Rediģēt notikumu",
    "Delete Event" : "Dzēst notikumu",
    "Save Event" : "Saglabāt notikumu",
    "Time" : "Laiks",
    "Type" : "Tips",
    "Relative" : "Relatīvs",
    "Absolute" : "Absolūts",
    "Repeat" : "Atkārtot",
    "times every" : "reizes katru",
    "Email reminders have not been implemented in the CalDAV server yet, so none will be sent." : "E-pasta atgādinājumi nav vēl pieejami CalDAV serverī, tāpēc tie netiks sūtīti.",
    "Add" : "Pievienot",
    "Email address of attendee" : "Dalībnieka e-pasta adrese",
    "Please add your email address in the personal settings in order to add attendees." : "Lai pievienotu dalībniekus, personīgajos iestatījumos pievieno savu e-pasta adresi",
    "from" : "no",
    "to" : "līdz",
    "This event's repeating rule is not supported yet." : "Šī notikuma atkārtošanās vēl netiek atbalstīta.",
    "Support for advanced rules will be added with subsequent updates." : "Uzlaboti noteikumi tiks pievienotu turpmākajos atjauninājumos.",
    "Reset repeating rule" : "Dzēst atkārtošanās noteikumu",
    "Repeat every ..." : "Atkārtot katru ...",
    "end repeat ..." : "un atkārtot ...",
    "times" : "reizes",
    "Import Calendars" : "Importēt kalendārus",
    "Import canceled" : "Imports atcelts",
    "Analyzing calendar" : "Analizē kalendāru",
    "The file contains objects incompatible with the selected calendar" : "Datne satur nesaderīgu objektu ar izvēlēto kalendāru",
    "New calendar" : "Jauns kalendārs",
    "File is empty" : "Datne ir tukša",
    "File could not be parsed" : "Datni nevarēja parsēt",
    "Import scheduled" : "Imports ielikts grafikā",
    "%s shared the calendar <strong>%s</strong> with you" : "%s koplietoja kalendāru <strong>%s</strong> ar jums",
    "Embed" : "Iestrādāt",
    "Iframe to integrate" : "Iframe, ko iestrādāt",
    "Publish URL" : "Publicēt URL",
    "Settings & import" : "Iestatījumi un imports",
    "Import calendar" : "Importēt kalendāru",
    "No Calendars selected for import" : "Nav izvēlēti kalendāri importēšai",
    "Skip simple event editor" : "Izlaist vienkāršoto notikuma redaktoru",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Timezone" : "Laika josla",
    "Primary CalDAV address" : "Primārā CalDAV adrese",
    "iOS/macOS CalDAV address" : "IOS/macOS CalDAV adrese",
    "Subscribe" : "Abonēt"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-calendar-1%3A2.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/lv.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendārs",
    "%s has published the calendar »%s«" : "%s dalijās ar kalendāru »%s«",
    "Hello," : "Sveicināti,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Mēs jūs vēlējāmies informēt, ka %s publicēja kalendāru »%s«.",
    "Open »%s«" : "Atvērt »%s«",
    "Cheers!" : "Priekā!",
    "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
    "Today" : "Šodien",
    "Day" : "Diena",
    "Week" : "Nedēļa",
    "Month" : "Mēnesis",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "Share link" : "Koplietot saiti",
    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
    "No users or groups" : "Nav lietotāji vai grupas",
    "can edit" : "var rediģēt",
    "New calendar" : "Jauns kalendārs",
    "Filename" : "Datnes nosaukums",
    "Cancel" : "Atcelt",
    "Automatic" : "Automātisks",
    "Show week numbers" : "Rādīt nedēļu numurus",
    "Settings & import" : "Iestatījumi un imports",
    "Notification" : "Paziņojums",
    "Email" : "E-pasts",
    "Busy" : "Aizņemts",
    "Unknown" : "Nezināms",
    "All day" : "Visas dienas",
    "from" : "no",
    "to" : "līdz",
    "never" : "nekad",
    "after" : "pēc",
    "Repeat" : "Atkārtot",
    "Monday" : "Pirmdiena",
    "Summary" : "Kopsavilkums",
    "More" : "Vairāk",
    "Save" : "Saglabāt",
    "Update" : "Atjaunināt",
    "Select Date" : "Izvēlieties datumu",
    "Personal" : "Personīgs",
    "Details" : "Detaļas",
    "Attendees" : "Apmeklētāji",
    "Reminders" : "Atgādinājumi",
    "Activity" : "Darbības",
    "Projects" : "Projekti",
    "Close" : "Aizvērt",
    "Anniversary" : "Gadadiena",
    "Week {number} of {year}" : "{number} nedēļa no {year}",
    "Daily" : "Katru dienu",
    "Weekly" : "Katru nedēļu",
    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
    "Location" : "Vieta",
    "Description" : "Apraksts",
    "Status" : "Status",
    "Confirmed" : "Apstiprināts",
    "Tentative" : "Mēģinājums",
    "Cancelled" : "Atcelts",
    "Categories" : "Kategorijas",
    "Presentation" : "Prezentācija",
    "Mail" : "E-pasts",
    "Play" : "Atskaņot",
    "Global" : "Globāls"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
